@@ -1,10 +1,11 @@
 use strict;
 use warnings;
 package Math::Shape::Range;
-$Math::Shape::Range::VERSION = '0.07';
+$Math::Shape::Range::VERSION = '0.08';
 use 5.008;
 use Carp;
 use Math::Shape::Utils;
+use List::Util qw/min max/;
 
 # ABSTRACT: a range object which has min and max values
 
@@ -37,6 +38,19 @@ sub is_overlapping
     overlap($_[0]->{min}, $_[0]->{max}, $_[1]->{min}, $_[1]->{max});
 }
 
+
+sub get_hull
+{
+    croak 'Must provide another Math::Shape::Range object as argument' unless $_[1]->isa('Math::Shape::Range');
+    my ($self, $other_range) = @_;
+
+    my $min = min $self->{min}, $other_range->{min};
+    my $max = max $self->{max}, $other_range->{max};
+
+    Math::Shape::Range->new($min, $max);
+}
+
+
 1;
 
 __END__
@@ -51,7 +65,7 @@ Math::Shape::Range - a range object which has min and max values
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 METHODS
 
@@ -77,6 +91,10 @@ Boolean method which returns 1 if the range object overlaps with another range,
     $range1->is_overlapping($range2); # 0
     $range2->is_overlapping($range3); # 1
 
+=head2 get_hull
+
+Returns a new Range object of the hull of two ranges. Requires another Math::Shape::Range object as an argument.
+
 =head1 AUTHOR
 
 David Farrell <sillymoos@cpan.org>
